<?php

namespace Annie\Activity\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Activity\Http\Requests\ActivityCollageRequest;
use Annie\Activity\Interfaces\ActivityCollageRepositoryInterface;
use Annie\Activity\Models\ActivityCollage;

/**
 * Resource controller class for activity_collage.
 */
class ActivityCollageResourceController extends BaseController
{

    /**
     * Initialize activity_collage resource controller.
     *
     * @param type ActivityCollageRepositoryInterface $activity_collage
     *
     * @return null
     */
    public function __construct(ActivityCollageRepositoryInterface $activity_collage)
    {
        parent::__construct();
        $this->repository = $activity_collage;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Activity\Repositories\Criteria\ActivityCollageResourceCriteria::class);
    }

    /**
     * Display a list of activity_collage.
     *
     * @return Response
     */
    public function index(ActivityCollageRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Activity\Repositories\Presenter\ActivityCollagePresenter::class)
                ->$function();
        }

        $activity_collages = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('activity::activity_collage.names'))
            ->view('activity::activity_collage.index', true)
            ->data(compact('activity_collages', 'view'))
            ->output();
    }

    /**
     * Display activity_collage.
     *
     * @param Request $request
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function show(ActivityCollageRequest $request, ActivityCollage $activity_collage)
    {

        if ($activity_collage->exists) {
            $view = 'activity::activity_collage.show';
        } else {
            $view = 'activity::activity_collage.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('activity::activity_collage.name'))
            ->data(compact('activity_collage'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_collage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityCollageRequest $request)
    {

        $activity_collage = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('activity::activity_collage.name')) 
            ->view('activity::activity_collage.create', true) 
            ->data(compact('activity_collage'))
            ->output();
    }

    /**
     * Create new activity_collage.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityCollageRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_collage                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('activity::activity_collage.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_collage/' . $activity_collage->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/activity/activity_collage'))
                ->redirect();
        }

    }

    /**
     * Show activity_collage for editing.
     *
     * @param Request $request
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function edit(ActivityCollageRequest $request, ActivityCollage $activity_collage)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('activity::activity_collage.name'))
            ->view('activity::activity_collage.edit', true)
            ->data(compact('activity_collage'))
            ->output();
    }

    /**
     * Update the activity_collage.
     *
     * @param Request $request
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function update(ActivityCollageRequest $request, ActivityCollage $activity_collage)
    {
        try {
            $attributes = $request->all();

            $activity_collage->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('activity::activity_collage.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_collage/' . $activity_collage->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_collage/' . $activity_collage->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_collage.
     *
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function destroy(ActivityCollageRequest $request, ActivityCollage $activity_collage)
    {
        try {

            $activity_collage->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_collage.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('activity/activity_collage/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_collage/' . $activity_collage->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_collage.
     *
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function delete(ActivityCollageRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_collage.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('activity/activity_collage'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_collage'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_collages.
     *
     * @param Model   $activity_collage
     *
     * @return Response
     */
    public function restore(ActivityCollageRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('activity::activity_collage.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/activity/activity_collage'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_collage/'))
                ->redirect();
        }

    }

}
