<?php

namespace Annie\Activity\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Activity\Http\Requests\ActivitySchoolRequest;
use Annie\Activity\Interfaces\ActivitySchoolRepositoryInterface;
use Annie\Activity\Models\ActivitySchool;

/**
 * Resource controller class for activity_school.
 */
class ActivitySchoolResourceController extends BaseController
{

    /**
     * Initialize activity_school resource controller.
     *
     * @param type ActivitySchoolRepositoryInterface $activity_school
     *
     * @return null
     */
    public function __construct(ActivitySchoolRepositoryInterface $activity_school)
    {
        parent::__construct();
        $this->repository = $activity_school;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Activity\Repositories\Criteria\ActivitySchoolResourceCriteria::class);
    }

    /**
     * Display a list of activity_school.
     *
     * @return Response
     */
    public function index(ActivitySchoolRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Activity\Repositories\Presenter\ActivitySchoolPresenter::class)
                ->$function();
        }

        $activity_schools = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('activity::activity_school.names'))
            ->view('activity::activity_school.index', true)
            ->data(compact('activity_schools', 'view'))
            ->output();
    }

    /**
     * Display activity_school.
     *
     * @param Request $request
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function show(ActivitySchoolRequest $request, ActivitySchool $activity_school)
    {

        if ($activity_school->exists) {
            $view = 'activity::activity_school.show';
        } else {
            $view = 'activity::activity_school.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('activity::activity_school.name'))
            ->data(compact('activity_school'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_school.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivitySchoolRequest $request)
    {

        $activity_school = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('activity::activity_school.name')) 
            ->view('activity::activity_school.create', true) 
            ->data(compact('activity_school'))
            ->output();
    }

    /**
     * Create new activity_school.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivitySchoolRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_school                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('activity::activity_school.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_school/' . $activity_school->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/activity/activity_school'))
                ->redirect();
        }

    }

    /**
     * Show activity_school for editing.
     *
     * @param Request $request
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function edit(ActivitySchoolRequest $request, ActivitySchool $activity_school)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('activity::activity_school.name'))
            ->view('activity::activity_school.edit', true)
            ->data(compact('activity_school'))
            ->output();
    }

    /**
     * Update the activity_school.
     *
     * @param Request $request
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function update(ActivitySchoolRequest $request, ActivitySchool $activity_school)
    {
        try {
            $attributes = $request->all();

            $activity_school->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('activity::activity_school.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_school/' . $activity_school->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_school/' . $activity_school->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_school.
     *
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function destroy(ActivitySchoolRequest $request, ActivitySchool $activity_school)
    {
        try {

            $activity_school->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_school.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('activity/activity_school/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_school/' . $activity_school->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_school.
     *
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function delete(ActivitySchoolRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_school.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('activity/activity_school'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_school'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_schools.
     *
     * @param Model   $activity_school
     *
     * @return Response
     */
    public function restore(ActivitySchoolRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('activity::activity_school.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/activity/activity_school'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_school/'))
                ->redirect();
        }

    }

}
