<?php

namespace Annie\Activity\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Annie\Activity\Http\Requests\ActivityWorkAreaRequest;
use Annie\Activity\Interfaces\ActivityWorkAreaRepositoryInterface;
use Annie\Activity\Models\ActivityWorkArea;

/**
 * Resource controller class for activity_work_area.
 */
class ActivityWorkAreaResourceController extends BaseController
{

    /**
     * Initialize activity_work_area resource controller.
     *
     * @param type ActivityWorkAreaRepositoryInterface $activity_work_area
     *
     * @return null
     */
    public function __construct(ActivityWorkAreaRepositoryInterface $activity_work_area)
    {
        parent::__construct();
        $this->repository = $activity_work_area;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Annie\Activity\Repositories\Criteria\ActivityWorkAreaResourceCriteria::class);
    }

    /**
     * Display a list of activity_work_area.
     *
     * @return Response
     */
    public function index(ActivityWorkAreaRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Annie\Activity\Repositories\Presenter\ActivityWorkAreaPresenter::class)
                ->$function();
        }

        $activity_work_areas = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('activity::activity_work_area.names'))
            ->view('activity::activity_work_area.index', true)
            ->data(compact('activity_work_areas', 'view'))
            ->output();
    }

    /**
     * Display activity_work_area.
     *
     * @param Request $request
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function show(ActivityWorkAreaRequest $request, ActivityWorkArea $activity_work_area)
    {

        if ($activity_work_area->exists) {
            $view = 'activity::activity_work_area.show';
        } else {
            $view = 'activity::activity_work_area.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('activity::activity_work_area.name'))
            ->data(compact('activity_work_area'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new activity_work_area.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActivityWorkAreaRequest $request)
    {

        $activity_work_area = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('activity::activity_work_area.name')) 
            ->view('activity::activity_work_area.create', true) 
            ->data(compact('activity_work_area'))
            ->output();
    }

    /**
     * Create new activity_work_area.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActivityWorkAreaRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $activity_work_area                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('activity::activity_work_area.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_work_area/' . $activity_work_area->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/activity/activity_work_area'))
                ->redirect();
        }

    }

    /**
     * Show activity_work_area for editing.
     *
     * @param Request $request
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function edit(ActivityWorkAreaRequest $request, ActivityWorkArea $activity_work_area)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('activity::activity_work_area.name'))
            ->view('activity::activity_work_area.edit', true)
            ->data(compact('activity_work_area'))
            ->output();
    }

    /**
     * Update the activity_work_area.
     *
     * @param Request $request
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function update(ActivityWorkAreaRequest $request, ActivityWorkArea $activity_work_area)
    {
        try {
            $attributes = $request->all();

            $activity_work_area->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('activity::activity_work_area.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('activity/activity_work_area/' . $activity_work_area->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_work_area/' . $activity_work_area->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the activity_work_area.
     *
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function destroy(ActivityWorkAreaRequest $request, ActivityWorkArea $activity_work_area)
    {
        try {

            $activity_work_area->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_work_area.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('activity/activity_work_area/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('activity/activity_work_area/' . $activity_work_area->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple activity_work_area.
     *
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function delete(ActivityWorkAreaRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('activity::activity_work_area.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('activity/activity_work_area'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_work_area'))
                ->redirect();
        }

    }

    /**
     * Restore deleted activity_work_areas.
     *
     * @param Model   $activity_work_area
     *
     * @return Response
     */
    public function restore(ActivityWorkAreaRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('activity::activity_work_area.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/activity/activity_work_area'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/activity/activity_work_area/'))
                ->redirect();
        }

    }

}
